import { ChangeDetectorRef, ElementRef, EventEmitter, OnDestroy, OnInit, TemplateRef } from '@angular/core';
import { SkyAppWindowRef } from '@skyux/core';
import { SkyLibResourcesService } from '@skyux/i18n';
import { SkyInlineFormAdapterService } from './inline-form-adapter.service';
import { SkyInlineFormButtonConfig } from './types/inline-form-button-config';
import { SkyInlineFormCloseArgs } from './types/inline-form-close-args';
import { SkyInlineFormConfig } from './types/inline-form-config';
import * as i0 from "@angular/core";
/**
 * Renders form content in the current view instead of a separate modal.
 */
export declare class SkyInlineFormComponent implements OnInit, OnDestroy {
    #private;
    /**
     * Configuration options for the buttons to display with the inline form.
     * @required
     */
    set config(value: SkyInlineFormConfig | undefined);
    get config(): SkyInlineFormConfig | undefined;
    /**
     * The template to instantiate the inline form.
     * @required
     */
    template: TemplateRef<unknown> | undefined;
    /**
     * Whether to display the inline form. Users can toggle between displaying
     * and hiding the inline form.
     * @default false
     */
    set showForm(value: boolean | undefined);
    get showForm(): boolean | undefined;
    get showFormData(): boolean | undefined;
    /**
     * Fires when users close the inline form.
     */
    close: EventEmitter<SkyInlineFormCloseArgs>;
    buttons: SkyInlineFormButtonConfig[];
    constructor(adapter: SkyInlineFormAdapterService, elementRef: ElementRef, resourcesService: SkyLibResourcesService, skyAppWindowRef: SkyAppWindowRef, changeDetectorRef: ChangeDetectorRef);
    ngOnInit(): void;
    ngOnDestroy(): void;
    closeInlineForm(event: SkyInlineFormButtonConfig): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<SkyInlineFormComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SkyInlineFormComponent, "sky-inline-form", never, { "config": { "alias": "config"; "required": false; }; "template": { "alias": "template"; "required": false; }; "showForm": { "alias": "showForm"; "required": false; }; }, { "close": "close"; }, never, ["*"], false, never>;
}
